@@ -77,7 +77,7 @@ static void main_window_zoom_in_cb (GtkWidget *, gpointer);
 static void main_window_zoom_out_cb (GtkWidget *, gpointer);
 static void main_window_zoom_width_cb (GtkToggleAction *, gpointer);
 static void main_window_set_page_mode (GtkRadioAction *, GtkRadioAction *, gpointer);
-static void main_window_page_scrolled_cb (GtkWidget *widget, GdkEventScroll *event, gpointer data);
+static gboolean main_window_page_scrolled_cb (GtkWidget *widget, GdkEventScroll *event, gpointer data);
 
 #if defined (HAVE_CUPS)
 static void main_window_print_cb (GtkWidget *, gpointer);
@@ -314,6 +314,15 @@ MainView::activePageModeText (gboolean active)
     gtk_toggle_action_set_active (GTK_TOGGLE_ACTION (action), active);
 }
 
+gboolean
+MainView::isIndexVisible () const
+{
+    GtkAction *showIndex =
+        gtk_ui_manager_get_action (m_UIManager,
+                                   "/MenuBar/ViewMenu/ShowIndex");
+    return gtk_toggle_action_get_active(GTK_TOGGLE_ACTION (showIndex));
+}
+
 gchar *
 MainView::openFileDialog (const gchar *lastFolder)
 {
@@ -431,6 +440,8 @@ MainView::saveFileDialog (const gchar *lastFolder, const gchar *fileName)
             GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
             GTK_STOCK_SAVE, GTK_RESPONSE_ACCEPT,
             NULL);
+    gtk_file_chooser_set_do_overwrite_confirmation (
+            GTK_FILE_CHOOSER (saveDialog), TRUE);
     gtk_dialog_set_alternative_button_order (GTK_DIALOG (saveDialog),
             GTK_RESPONSE_ACCEPT, GTK_RESPONSE_CANCEL, -1);
 
@@ -1127,7 +1138,7 @@ main_window_about_box_cb (GtkWidget *widget, gpointer data)
     gtk_show_about_dialog (NULL,
             "name", _("ePDFView"),
             "version", VERSION,
-            "copyright", "\xc2\xa9 2006, 2007, 2009 Emma's Software",
+            "copyright", "\xc2\xa9 2006, 2007, 2009, 2010, 2011 Emma's Software",
             "license", licenseTranslated,
             "website", "http://www.emma-soft.com/projects/epdfview/",
             "authors", authors,
@@ -1479,18 +1490,25 @@ main_window_set_page_mode (GtkRadioAction *action, GtkRadioAction *current, gpoi
     pter->setPageMode (mode);
 }
 
-void 
+gboolean 
 main_window_page_scrolled_cb (GtkWidget *widget, GdkEventScroll *event, gpointer data)
 {
     g_assert ( NULL != data && "The data parameter is NULL.");
 
     MainPter *pter = (MainPter *)data;
     // Only zoom when the CTRL-Button is down...
-    if ( !(event->state & GDK_CONTROL_MASK) ) return;
-    if ( event->direction == GDK_SCROLL_UP ) {
-        pter->zoomInActivated ();
-    } else if ( event->direction == GDK_SCROLL_DOWN ) {
-        pter->zoomOutActivated ();
+    if ( GDK_CONTROL_MASK == (event->state & GDK_CONTROL_MASK) )
+    {
+        if ( event->direction == GDK_SCROLL_UP )
+        {
+            pter->zoomInActivated ();
+        }
+        else if ( event->direction == GDK_SCROLL_DOWN )
+        {
+            pter->zoomOutActivated ();
+        }
+        return TRUE;
     }
+    return FALSE;
 }
 
